package com.miaxis.app.hospital.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.miaxis.app.hospital.domain.HospitalInfo;

/**
 * 体检医院Mapper接口
 *
 * @author miaxis
 * @date 2021-01-11
 */
public interface HospitalInfoMapper extends BaseMapper<HospitalInfo> {
    /**
     * 查询体检医院
     *
     * @param id 体检医院ID
     * @return 体检医院
     */
    public HospitalInfo selectHospitalInfoById(Long id);

    /**
     * 查询体检医院列表
     *
     * @param hospitalInfo 体检医院
     * @return 体检医院集合
     */
    public List<HospitalInfo> selectHospitalInfoList(HospitalInfo hospitalInfo);

    /**
     * 新增体检医院
     *
     * @param hospitalInfo 体检医院
     * @return 结果
     */
    public int insertHospitalInfo(HospitalInfo hospitalInfo);

    /**
     * 修改体检医院
     *
     * @param hospitalInfo 体检医院
     * @return 结果
     */
    public int updateHospitalInfo(HospitalInfo hospitalInfo);

    /**
     * 删除体检医院
     *
     * @param id 体检医院ID
     * @return 结果
     */
    public int deleteHospitalInfoById(Long id);

    /**
     * 批量删除体检医院
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteHospitalInfoByIds(Long[] ids);
}
